pub enum AmountAdjustmentReason {
FlooredToMinLimit,
IncreasedToAvoidDust,
}Expand description
The reason why a conversion amount was adjusted from the originally requested value.
Variants
FlooredToMinLimit
The amount was increased to meet the minimum conversion limit.
IncreasedToAvoidDust
The amount was increased to convert the full token balance, avoiding a remaining balance below the minimum conversion limit (token dust).