pub struct ConversionEstimate {
pub options: ConversionOptions,
pub amount_in: u128,
pub amount_out: u128,
pub fee: u128,
pub amount_adjustment: Option<AmountAdjustmentReason>,
}Expand description
Response from estimating a conversion, used when preparing a payment that requires conversion
Fields
options: ConversionOptionsThe conversion options used for the estimate
amount_in: u128The input amount for the conversion.
For FromBitcoin: the satoshis required to produce the desired token output.
For ToBitcoin: the token amount being converted.
amount_out: u128The estimated output amount from the conversion.
For FromBitcoin: the estimated token amount received.
For ToBitcoin: the estimated satoshis received.
fee: u128The fee estimated for the conversion. Denominated in satoshis if converting from Bitcoin, otherwise in the token base units.
amount_adjustment: Option<AmountAdjustmentReason>The reason the conversion amount was adjusted, if applicable.