pub struct FetchConversionLimitsResponse {
pub min_from_amount: Option<u128>,
pub min_to_amount: Option<u128>,
}Fields
min_from_amount: Option<u128>The minimum amount to be converted. Denominated in satoshis if converting from Bitcoin, otherwise in the token base units.
min_to_amount: Option<u128>The minimum amount to be received from the conversion. Denominated in satoshis if converting to Bitcoin, otherwise in the token base units.